@@ -1,5 +1,5 @@
 package Devel::StackTrace;
-$Devel::StackTrace::VERSION = '1.32';
+$Devel::StackTrace::VERSION = '1.33';
 use 5.006;
 
 use strict;
@@ -39,8 +39,9 @@ sub _record_caller_data {
 
     my $filter = $self->{filter_frames_early} && $self->_make_frame_filter();
 
-    # We exclude this method by starting one frame back.
-    my $x = 1;
+    # We exclude this method by starting at least one frame back.
+    my $x = 1 + ( $self->{skip_frames} // 0 );
+
     while (
         my @c
         = $self->{no_args}
@@ -267,7 +268,7 @@ Devel::StackTrace - An object representing a stack trace
 
 =head1 VERSION
 
-version 1.32
+version 1.33
 
 =head1 SYNOPSIS
 
@@ -373,6 +374,13 @@ parameter, meaning that the Devel::StackTrace package is B<ALWAYS>
 ignored. However, if you create a subclass of Devel::StackTrace it
 will not be ignored.
 
+=item * skip_frames => $integer
+
+This will cause this number of stack frames to be excluded from top of the
+stack trace. This prevents the frames from being captured at all, and applies
+before the C<frame_filter>, C<ignore_package>, or C<ignore_class> options,
+even with C<filter_frames_early>.
+
 =item * no_refs => $boolean
 
 If this parameter is true, then Devel::StackTrace will not store
